@@ -469,7 +469,7 @@ class WordType(caching.base.CachingMixin,models.Model):
             patt.append(any_segment)
             patt.extend(phones[i:])
             patterns.append('^'+' '.join(patt) +'$')
-        neighs = qs.filter(ur__regex = '|'.join(patterns)
+        neighs = qs.filter(ur__regex = '|'.join(patterns))
         nd = len(neighs)
         fwnd = sum([ x.getFreq() for x in neighs])
         self.ND = neighCount
